@@ -24,12 +24,11 @@
 
 #include <QWidget>
 
-#include "logMode.h"
 #include "logFile.h"
+#include "logMode.h"
 
 class QProgressBar;
-class LoadingBarPrivate;
-
+class QLabel;
 /**
  * TODO Try to have a working Cancel button (for the moment, it only hide the Loading Dialog)
  */
@@ -40,9 +39,9 @@ class LoadingBar : public QWidget
 public:
     explicit LoadingBar(QWidget *parent = nullptr);
 
-    ~LoadingBar();
+    ~LoadingBar() override;
 
-    QProgressBar *progressBar();
+    QProgressBar *progressBar() const;
 
 public Q_SLOTS:
 
@@ -55,7 +54,11 @@ Q_SIGNALS:
     void displayed(bool displayed);
 
 private:
-    LoadingBarPrivate *const d;
+    bool mFirstLoading = true;
+
+    QLabel *mLabel = nullptr;
+
+    QProgressBar *mProgressBar = nullptr;
 };
 
 #endif // _LOADING_BAR_H
