@@ -24,9 +24,9 @@
 
 #include <KLocalizedString>
 
+#include "fileList.h"
 #include "globals.h"
 #include "logging.h"
-#include "fileList.h"
 
 #include "logLevel.h"
 
@@ -42,59 +42,25 @@ class AcpidConfigurationWidget : public LogModeConfigurationWidget
     Q_OBJECT
 
 public:
-    AcpidConfigurationWidget()
-        : LogModeConfigurationWidget(i18n("Acpid Log"), QStringLiteral(ACPID_MODE_ICON), i18n("Acpid Log"))
+    AcpidConfigurationWidget();
+
+    ~AcpidConfigurationWidget() override
     {
-        QHBoxLayout *layout = new QHBoxLayout(this);
-
-        fileList
-            = new FileList(this, i18n("<p>These files will be analyzed to show the <b>Acpid log</b>.</p>"));
-        connect(fileList, &FileList::fileListChanged, this, &LogModeConfigurationWidget::configurationChanged);
-        layout->addWidget(fileList);
     }
 
-    ~AcpidConfigurationWidget() override {}
-
 public Q_SLOTS:
 
-    void saveConfig() override
-    {
-        AcpidConfiguration *acpidConfiguration = Globals::instance()
-                                                     .findLogMode(QStringLiteral(ACPID_LOG_MODE_ID))
-                                                     ->logModeConfiguration<AcpidConfiguration *>();
+    void saveConfig() override;
 
-        acpidConfiguration->setAcpidPaths(fileList->paths());
-    }
+    void readConfig() override;
 
-    void readConfig() override
-    {
-        AcpidConfiguration *acpidConfiguration = Globals::instance()
-                                                     .findLogMode(QStringLiteral(ACPID_LOG_MODE_ID))
-                                                     ->logModeConfiguration<AcpidConfiguration *>();
-
-        fileList->removeAllItems();
-
-        fileList->addPaths(acpidConfiguration->acpidPaths());
-    }
-
-    void defaultConfig() override
-    {
-        // TODO Find a way to read the configuration per default
-        readConfig();
-    }
+    void defaultConfig() override;
 
 protected:
-    bool isValid() const override
-    {
-        if (fileList->isEmpty() == false) {
-            return true;
-        }
-
-        return false;
-    }
+    bool isValid() const override;
 
 private:
-    FileList *fileList;
+    FileList *mFileList = nullptr;
 };
 
 #endif // _ACPID_CONFIGURATION_WIDGET_H
