@@ -46,14 +46,13 @@ class CupsLogMode : public LogMode
     Q_OBJECT
 
 public:
-    explicit CupsLogMode(QSharedPointer<CupsConfiguration> &cupsConfiguration,
-                         CupsConfigurationWidget *cupsConfigurationWidget);
+    explicit CupsLogMode(QSharedPointer<CupsConfiguration> &cupsConfiguration, CupsConfigurationWidget *cupsConfigurationWidget);
 
-    ~CupsLogMode();
+    ~CupsLogMode() override;
 
     Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;
 
-    QList<LogFile> createLogFiles() override;
+    QVector<LogFile> createLogFiles() override;
 };
 
 #endif // _CUPS_LOG_MODE_H
