@@ -45,11 +45,11 @@ class XSessionLogMode : public LogMode
 public:
     explicit XSessionLogMode();
 
-    ~XSessionLogMode();
+    ~XSessionLogMode() override;
 
     Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;
 
-    QList<LogFile> createLogFiles() override;
+    QVector<LogFile> createLogFiles() override;
 };
 
 #endif // _X_SESSION_LOG_MODE_H
