@@ -27,62 +27,49 @@
 
 #include "view.h"
 
-#include "logMode.h"
 #include "defaults.h"
 #include "logManager.h"
-
-class TabLogManagerPrivate
-{
-public:
-    LogManager *logManager;
-    int newLinesCount;
-};
+#include "logMode.h"
 
 TabLogManager::TabLogManager(LogManager *logManager)
-    : d(new TabLogManagerPrivate())
+    : mLogManager(logManager)
 {
-    d->logManager = logManager;
-
-    d->newLinesCount = 0;
 }
 
 TabLogManager::~TabLogManager()
 {
-    delete d->logManager->usedView();
-
-    delete d->logManager;
-
-    delete d;
+    // delete mLogManager->usedView();
 }
 
-LogManager *TabLogManager::logManager()
+LogManager *TabLogManager::logManager() const
 {
-    return d->logManager;
+    return mLogManager;
 }
 
 void TabLogManager::addNewLinesCount(int newLines)
 {
-    d->newLinesCount += newLines;
+    mNewLinesCount += newLines;
 }
 
 void TabLogManager::initNewLinesCount()
 {
-    d->newLinesCount = 0;
+    mNewLinesCount = 0;
 }
 
-QString TabLogManager::title()
+QString TabLogManager::title() const
 {
-    if (d->newLinesCount == 0)
+    if (mNewLinesCount == 0) {
         return logModeName();
-    else
-        return i18nc("Log mode name (added lines count)", "%1 (%2)", d->logManager->title(),
-                     d->newLinesCount);
+    } else {
+        return i18nc("Log mode name (added lines count)", "%1 (%2)", mLogManager->title(), mNewLinesCount);
+    }
 }
 
-QString TabLogManager::logModeName()
+QString TabLogManager::logModeName() const
 {
-    if (d->logManager->logMode() == nullptr)
+    if (!mLogManager->logMode()) {
         return i18nc("Newly created tab", "Empty Log");
-    else
-        return d->logManager->title();
+    } else {
+        return mLogManager->title();
+    }
 }
